@@ -37,9 +37,8 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <gdk/gdkkeysyms.h>
+#include <gdk/gdk.h>
 
-#include <gtk/gtkbindings.h>
 #include <gtk/gtk.h>
 
 #include "gdict-source-chooser.h"
